pub enum FinalizeType<N>where
N: Network,{
Plaintext(PlaintextType<N>),
Future(Locator<N>),
}Variants
Implementations
Sourceimpl<N> FinalizeType<N>where
N: Network,
impl<N> FinalizeType<N>where
N: Network,
Sourcepub fn future_size_in_bits<F0, F1, F2>(
locator: &Locator<N>,
get_struct: &F0,
get_external_struct: &F1,
get_future: &F2,
) -> Result<usize, Error>where
F0: Fn(&Identifier<N>) -> Result<StructType<N>, Error>,
F1: Fn(&Locator<N>) -> Result<StructType<N>, Error>,
F2: Fn(&Locator<N>) -> Result<Vec<FinalizeType<N>>, Error>,
pub fn future_size_in_bits<F0, F1, F2>(
locator: &Locator<N>,
get_struct: &F0,
get_external_struct: &F1,
get_future: &F2,
) -> Result<usize, Error>where
F0: Fn(&Identifier<N>) -> Result<StructType<N>, Error>,
F1: Fn(&Locator<N>) -> Result<StructType<N>, Error>,
F2: Fn(&Locator<N>) -> Result<Vec<FinalizeType<N>>, Error>,
Returns the number of bits of a finalize type.
Note. The plaintext variant is assumed to be an argument of a Future and this does not have a “raw” serialization.
Sourcepub fn future_size_in_bits_raw<F0, F1, F2>(
locator: &Locator<N>,
get_struct: &F0,
get_external_struct: &F1,
get_future: &F2,
) -> Result<usize, Error>where
F0: Fn(&Identifier<N>) -> Result<StructType<N>, Error>,
F1: Fn(&Locator<N>) -> Result<StructType<N>, Error>,
F2: Fn(&Locator<N>) -> Result<Vec<FinalizeType<N>>, Error>,
pub fn future_size_in_bits_raw<F0, F1, F2>(
locator: &Locator<N>,
get_struct: &F0,
get_external_struct: &F1,
get_future: &F2,
) -> Result<usize, Error>where
F0: Fn(&Identifier<N>) -> Result<StructType<N>, Error>,
F1: Fn(&Locator<N>) -> Result<StructType<N>, Error>,
F2: Fn(&Locator<N>) -> Result<Vec<FinalizeType<N>>, Error>,
Returns the number of raw bits of a finlaize type.