pub struct ProvingKey<N>where
N: Network,{ /* private fields */ }Implementations
Sourceimpl<N> ProvingKey<N>where
N: Network,
impl<N> ProvingKey<N>where
N: Network,
Sourcepub const fn new(
proving_key: Arc<CircuitProvingKey<<N as Environment>::PairingCurve, VarunaHidingMode>>,
) -> ProvingKey<N>
pub const fn new( proving_key: Arc<CircuitProvingKey<<N as Environment>::PairingCurve, VarunaHidingMode>>, ) -> ProvingKey<N>
Initializes a new proving key.
Sourcepub fn prove<R>(
&self,
_function_name: &str,
varuna_version: VarunaVersion,
assignment: &Assignment<<N as Environment>::Field>,
rng: &mut R,
) -> Result<Proof<N>, Error>
pub fn prove<R>( &self, _function_name: &str, varuna_version: VarunaVersion, assignment: &Assignment<<N as Environment>::Field>, rng: &mut R, ) -> Result<Proof<N>, Error>
Returns a proof for the given assignment on the circuit.
Sourcepub fn prove_batch<R>(
_locator: &str,
varuna_version: VarunaVersion,
assignments: &[(ProvingKey<N>, Vec<Assignment<<N as Environment>::Field>>)],
rng: &mut R,
) -> Result<Proof<N>, Error>
pub fn prove_batch<R>( _locator: &str, varuna_version: VarunaVersion, assignments: &[(ProvingKey<N>, Vec<Assignment<<N as Environment>::Field>>)], rng: &mut R, ) -> Result<Proof<N>, Error>
Returns a proof for the given batch of proving keys and assignments.