VM

Struct VM 

pub struct VM<N, C>
where N: Network, C: ConsensusStorage<N>,
{ /* private fields */ }

Implementations

Source

impl<N, C> VM<N, C>
where N: Network, C: ConsensusStorage<N>,

pub fn start_sequential_queue( &self, request_rx: Receiver<SequentialOperationRequest<N>>, ) -> JoinHandle<()>

Launches a thread dedicated to the sequential processing of storage-related operations.

pub fn run_sequential_operation( &self, op: SequentialOperation<N>, ) -> Option<SequentialOperationResult<N>>

Sends the given operation to the thread used for sequential processing.

pub fn ensure_sequential_processing(&self)

A safeguard used to ensure that the given operation is processed in the thread enforcing sequential processing of operations.

Source

impl<N, C> VM<N, C>
where N: Network, C: ConsensusStorage<N>,

pub fn authorize<R>( &self, private_key: &PrivateKey<N>, program_id: impl TryInto<ProgramID<N>>, function_name: impl TryInto<Identifier<N>>, inputs: impl IntoIterator<IntoIter = impl ExactSizeIterator<Item = impl TryInto<Value<N>>>>, rng: &mut R, ) -> Result<Authorization<N>, VmAuthError>
where R: Rng + CryptoRng,

Authorizes a call to the program function for the given inputs.

pub fn authorize_fee_private<R>( &self, private_key: &PrivateKey<N>, credits: Record<N, Plaintext<N>>, base_fee_in_microcredits: u64, priority_fee_in_microcredits: u64, deployment_or_execution_id: Field<N>, rng: &mut R, ) -> Result<Authorization<N>, Error>
where R: Rng + CryptoRng,

Authorizes the fee given the credits record, the fee amount (in microcredits), and the deployment or execution ID.

pub fn authorize_fee_public<R>( &self, private_key: &PrivateKey<N>, base_fee_in_microcredits: u64, priority_fee_in_microcredits: u64, deployment_or_execution_id: Field<N>, rng: &mut R, ) -> Result<Authorization<N>, Error>
where R: Rng + CryptoRng,

Authorizes the fee given the the fee amount (in microcredits) and the deployment or execution ID.

Source

impl<N, C> VM<N, C>
where N: Network, C: ConsensusStorage<N>,

pub fn deploy<R>( &self, private_key: &PrivateKey<N>, program: &ProgramCore<N>, fee_record: Option<Record<N, Plaintext<N>>>, priority_fee_in_microcredits: u64, query: Option<&dyn QueryTrait<N>>, rng: &mut R, ) -> Result<Transaction<N>, VmDeployError>
where R: Rng + CryptoRng,

Returns a new deploy transaction.

If a fee_record is provided, then a private fee will be included in the transaction; otherwise, a public fee will be included in the transaction.

The priority_fee_in_microcredits is an additional fee on top of the deployment fee.

Source

impl<N, C> VM<N, C>
where N: Network, C: ConsensusStorage<N>,

pub fn execute<R>( &self, private_key: &PrivateKey<N>, _: (impl TryInto<ProgramID<N>>, impl TryInto<Identifier<N>>), inputs: impl ExactSizeIterator<Item = impl TryInto<Value<N>>>, fee_record: Option<Record<N, Plaintext<N>>>, priority_fee_in_microcredits: u64, query: Option<&dyn QueryTrait<N>>, rng: &mut R, ) -> Result<Transaction<N>, VmExecError>
where R: Rng + CryptoRng,

Returns a new execute transaction.

If a fee_record is provided, then a private fee will be included in the transaction; otherwise, a public fee will be included in the transaction.

The priority_fee_in_microcredits is an additional fee on top of the execution fee.

pub fn execute_with_response<R>( &self, private_key: &PrivateKey<N>, _: (impl TryInto<ProgramID<N>>, impl TryInto<Identifier<N>>), inputs: impl ExactSizeIterator<Item = impl TryInto<Value<N>>>, fee_record: Option<Record<N, Plaintext<N>>>, priority_fee_in_microcredits: u64, query: Option<&dyn QueryTrait<N>>, rng: &mut R, ) -> Result<(Transaction<N>, Response<N>), VmExecError>
where R: Rng + CryptoRng,

Returns a new execute transaction and response.

If a fee_record is provided, then a private fee will be included in the transaction; otherwise, a public fee will be included in the transaction.

The priority_fee_in_microcredits is an additional fee on top of the execution fee.

pub fn execute_authorization<R>( &self, execute_authorization: Authorization<N>, fee_authorization: Option<Authorization<N>>, query: Option<&dyn QueryTrait<N>>, rng: &mut R, ) -> Result<Transaction<N>, Error>
where R: Rng + CryptoRng,

Returns a new execute transaction for the given authorization.

This is identical to execute_authorization_with_response except that it discards the Response.

pub fn execute_authorization_with_response<R>( &self, execute_authorization: Authorization<N>, fee_authorization: Option<Authorization<N>>, query: Option<&dyn QueryTrait<N>>, rng: &mut R, ) -> Result<(Transaction<N>, Response<N>), Error>
where R: Rng + CryptoRng,

Returns a new execute transaction and response for the given authorization.

pub fn execute_fee_authorization<R>( &self, authorization: Authorization<N>, query: Option<&dyn QueryTrait<N>>, rng: &mut R, ) -> Result<Fee<N>, VmExecError>
where R: Rng + CryptoRng,

Returns a new fee for the given authorization.

Source

impl<N, C> VM<N, C>
where N: Network, C: ConsensusStorage<N>,

pub fn speculate<'a, R>( &self, state: FinalizeGlobalState, time_since_last_block: i64, coinbase_reward: Option<u64>, candidate_ratifications: Vec<Ratify<N>>, candidate_solutions: &Solutions<N>, candidate_transactions: impl ExactSizeIterator<Item = &'a Transaction<N>>, rng: &mut R, ) -> Result<(Ratifications<N>, Transactions<N>, Vec<<N as Network>::TransactionID>, Vec<FinalizeOperation<N>>), Error>
where R: Rng + CryptoRng,

Speculates on the given list of transactions in the VM. This function aborts all transactions that are not are well-formed or unique.

Returns the confirmed transactions, aborted transaction IDs, and finalize operations from pre-ratify and post-ratify.

Note

This method is used to create a new block (including the genesis block).

  • If coinbase_reward = None, then the ratifications will not be modified.
  • If coinbase_reward = Some(coinbase_reward), then the method will append a Ratify::BlockReward(block_reward) and Ratify::PuzzleReward(puzzle_reward) to the front of the ratifications list.
Panics

This function panics if called from an async context.

pub fn check_speculate<R>( &self, state: FinalizeGlobalState, time_since_last_block: i64, ratifications: &Ratifications<N>, solutions: &Solutions<N>, transactions: &Transactions<N>, rng: &mut R, ) -> Result<Vec<FinalizeOperation<N>>, Error>
where R: Rng + CryptoRng,

Checks the speculation on the given transactions in the VM. This function also ensure that the given transactions are well-formed and unique.

Returns the finalize operations from pre-ratify and post-ratify.

Panics

This function panics if called from an async context.

pub fn finalize( &self, state: FinalizeGlobalState, ratifications: &Ratifications<N>, solutions: &Solutions<N>, transactions: &Transactions<N>, ) -> Result<Vec<FinalizeOperation<N>>, Error>

Finalizes the given transactions into the VM.

Returns the finalize operations from pre-ratify and post-ratify.

Source

impl<N, C> VM<N, C>
where N: Network, C: ConsensusStorage<N>,

pub const MAXIMUM_CONFIRMED_TRANSACTIONS: usize = Transactions<N>::MAX_TRANSACTIONS

The maximum number of confirmed transactions allowed in a block.

Source

impl<N, C> VM<N, C>
where N: Network, C: ConsensusStorage<N>,

pub const MAX_PARALLEL_DEPLOY_VERIFICATIONS: usize = 5

The maximum number of deployments that the VM can verify in parallel.

pub const MAX_PARALLEL_EXECUTE_VERIFICATIONS: usize = 1000

The maximum number of executions to verify in parallel.

pub fn check_transactions<R>( &self, transactions: &[(&Transaction<N>, Option<Field<N>>)], rng: &mut R, ) -> Result<(), Error>
where R: CryptoRng + Rng,

Verifies the list of transactions in the VM. On failure, returns an error.

Source

impl<N, C> VM<N, C>
where N: Network, C: ConsensusStorage<N>,

pub fn check_transaction<R>( &self, transaction: &Transaction<N>, rejected_id: Option<Field<N>>, rng: &mut R, ) -> Result<(), Error>
where R: CryptoRng + Rng,

Verifies the transaction in the VM. On failure, returns an error.

pub fn check_fee( &self, transaction: &Transaction<N>, rejected_id: Option<Field<N>>, is_partially_verified: bool, ) -> Result<(), Error>

Verifies the fee in the given transaction. On failure, returns an error.

Source

impl<N, C> VM<N, C>
where N: Network, C: ConsensusStorage<N>,

pub fn from(store: ConsensusStore<N, C>) -> Result<VM<N, C>, Error>

Initializes the VM from storage.

pub fn contains_program(&self, program_id: &ProgramID<N>) -> bool

Returns true if a program with the given program ID exists.

pub fn process(&self) -> Arc<RwLock<RawRwLock, Process<N>>>

Returns the process.

pub const fn puzzle(&self) -> &Puzzle<N>

Returns the puzzle.

pub fn partially_verified_transactions( &self, ) -> Arc<RwLock<RawRwLock, LruCache<(<N as Network>::TransactionID, Vec<Integer<N, u16>>), <N as Network>::TransmissionChecksum>>>

Returns the partially-verified transactions.

pub const fn restrictions(&self) -> &Restrictions<N>

Returns the restrictions.

Source

impl<N, C> VM<N, C>
where N: Network, C: ConsensusStorage<N>,

pub fn finalize_store( &self, ) -> &FinalizeStore<N, <C as ConsensusStorage<N>>::FinalizeStorage>

Returns the finalize store.

pub fn block_store( &self, ) -> &BlockStore<N, <C as ConsensusStorage<N>>::BlockStorage>

Returns the block store.

pub fn transaction_store( &self, ) -> &TransactionStore<N, <C as ConsensusStorage<N>>::TransactionStorage>

Returns the transaction store.

pub fn transition_store( &self, ) -> &TransitionStore<N, <C as ConsensusStorage<N>>::TransitionStorage>

Returns the transition store.

Source

impl<N, C> VM<N, C>
where N: Network, C: ConsensusStorage<N>,

pub fn new_puzzle() -> Result<Puzzle<N>, Error>

Returns a new instance of the puzzle.

Source

impl<N, C> VM<N, C>
where N: Network, C: ConsensusStorage<N>,

pub fn genesis_beacon<R>( &self, private_key: &PrivateKey<N>, rng: &mut R, ) -> Result<Block<N>, Error>
where R: Rng + CryptoRng,

Returns a new genesis block for a beacon chain with the default size (four validators).

pub fn genesis_beacon_with_size<R>( &self, private_key: &PrivateKey<N>, num_validators: usize, rng: &mut R, ) -> Result<Block<N>, Error>
where R: Rng + CryptoRng,

Returns a new genesis block for a beacon chain.

pub fn genesis_quorum<R>( &self, private_key: &PrivateKey<N>, committee: Committee<N>, public_balances: IndexMap<Address<N>, u64>, bonded_balances: IndexMap<Address<N>, (Address<N>, Address<N>, u64)>, rng: &mut R, ) -> Result<Block<N>, Error>
where R: Rng + CryptoRng,

Returns a new genesis block for a quorum chain.

Panics

This function panics if called from an async context.

pub fn add_next_block(&self, block: &Block<N>) -> Result<(), Error>

Adds the given block into the VM.

Panics

This function panics if called from an async context.