pub enum Instruction<N>where
N: Network,{
Show 119 variants
Abs(Literals<N, AbsOperation<N>, 1>),
AbsWrapped(Literals<N, AbsWrappedOperation<N>, 1>),
Add(Literals<N, AddOperation<N>, 2>),
AddWrapped(Literals<N, AddWrappedOperation<N>, 2>),
And(Literals<N, AndOperation<N>, 2>),
AssertEq(AssertInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::assert::AssertEq::{constant#0}>),
AssertNeq(AssertInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::assert::AssertNeq::{constant#0}>),
Async(Async<N>),
Call(Call<N>),
Cast(CastOperation<N, snarkvm_synthesizer_program::::logic::instruction::operation::cast::Cast::{constant#0}>),
CastLossy(CastOperation<N, snarkvm_synthesizer_program::::logic::instruction::operation::cast::CastLossy::{constant#0}>),
CommitBHP256(CommitInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::commit::CommitBHP256::{constant#0}>),
CommitBHP512(CommitInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::commit::CommitBHP512::{constant#0}>),
CommitBHP768(CommitInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::commit::CommitBHP768::{constant#0}>),
CommitBHP1024(CommitInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::commit::CommitBHP1024::{constant#0}>),
CommitPED64(CommitInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::commit::CommitPED64::{constant#0}>),
CommitPED128(CommitInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::commit::CommitPED128::{constant#0}>),
DeserializeBits(DeserializeInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::deserialize::DeserializeBits::{constant#0}>),
DeserializeBitsRaw(DeserializeInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::deserialize::DeserializeBitsRaw::{constant#0}>),
Div(Literals<N, DivOperation<N>, 2>),
DivWrapped(Literals<N, DivWrappedOperation<N>, 2>),
Double(Literals<N, DoubleOperation<N>, 1>),
ECDSAVerifyDigest(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyDigest::{constant#0}>),
ECDSAVerifyDigestEth(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyDigestEth::{constant#0}>),
ECDSAVerifyKeccak256(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak256::{constant#0}>),
ECDSAVerifyKeccak256Raw(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak256Raw::{constant#0}>),
ECDSAVerifyKeccak256Eth(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak256Eth::{constant#0}>),
ECDSAVerifyKeccak384(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak384::{constant#0}>),
ECDSAVerifyKeccak384Raw(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak384Raw::{constant#0}>),
ECDSAVerifyKeccak384Eth(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak384Eth::{constant#0}>),
ECDSAVerifyKeccak512(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak512::{constant#0}>),
ECDSAVerifyKeccak512Raw(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak512Raw::{constant#0}>),
ECDSAVerifyKeccak512Eth(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak512Eth::{constant#0}>),
ECDSAVerifySha3_256(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_256::{constant#0}>),
ECDSAVerifySha3_256Raw(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_256Raw::{constant#0}>),
ECDSAVerifySha3_256Eth(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_256Eth::{constant#0}>),
ECDSAVerifySha3_384(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_384::{constant#0}>),
ECDSAVerifySha3_384Raw(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_384Raw::{constant#0}>),
ECDSAVerifySha3_384Eth(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_384Eth::{constant#0}>),
ECDSAVerifySha3_512(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_512::{constant#0}>),
ECDSAVerifySha3_512Raw(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_512Raw::{constant#0}>),
ECDSAVerifySha3_512Eth(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_512Eth::{constant#0}>),
GreaterThan(Literals<N, GreaterThanOperation<N>, 2>),
GreaterThanOrEqual(Literals<N, GreaterThanOrEqualOperation<N>, 2>),
HashBHP256(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP256::{constant#0}>),
HashBHP256Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP256Raw::{constant#0}>),
HashBHP512(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP512::{constant#0}>),
HashBHP512Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP512Raw::{constant#0}>),
HashBHP768(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP768::{constant#0}>),
HashBHP768Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP768Raw::{constant#0}>),
HashBHP1024(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP1024::{constant#0}>),
HashBHP1024Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP1024Raw::{constant#0}>),
HashKeccak256(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak256::{constant#0}>),
HashKeccak256Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak256Raw::{constant#0}>),
HashKeccak256Native(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak256Native::{constant#0}>),
HashKeccak256NativeRaw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak256NativeRaw::{constant#0}>),
HashKeccak384(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak384::{constant#0}>),
HashKeccak384Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak384Raw::{constant#0}>),
HashKeccak384Native(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak384Native::{constant#0}>),
HashKeccak384NativeRaw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak384NativeRaw::{constant#0}>),
HashKeccak512(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak512::{constant#0}>),
HashKeccak512Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak512Raw::{constant#0}>),
HashKeccak512Native(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak512Native::{constant#0}>),
HashKeccak512NativeRaw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak512NativeRaw::{constant#0}>),
HashPED64(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPED64::{constant#0}>),
HashPED64Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPED64Raw::{constant#0}>),
HashPED128(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPED128::{constant#0}>),
HashPED128Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPED128Raw::{constant#0}>),
HashPSD2(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPSD2::{constant#0}>),
HashPSD2Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPSD2Raw::{constant#0}>),
HashPSD4(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPSD4::{constant#0}>),
HashPSD4Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPSD4Raw::{constant#0}>),
HashPSD8(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPSD8::{constant#0}>),
HashPSD8Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPSD8Raw::{constant#0}>),
HashSha3_256(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_256::{constant#0}>),
HashSha3_256Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_256Raw::{constant#0}>),
HashSha3_256Native(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_256Native::{constant#0}>),
HashSha3_256NativeRaw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_256NativeRaw::{constant#0}>),
HashSha3_384(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_384::{constant#0}>),
HashSha3_384Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_384Raw::{constant#0}>),
HashSha3_384Native(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_384Native::{constant#0}>),
HashSha3_384NativeRaw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_384NativeRaw::{constant#0}>),
HashSha3_512(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_512::{constant#0}>),
HashSha3_512Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_512Raw::{constant#0}>),
HashSha3_512Native(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_512Native::{constant#0}>),
HashSha3_512NativeRaw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_512NativeRaw::{constant#0}>),
HashManyPSD2(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashManyPSD2::{constant#0}>),
HashManyPSD4(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashManyPSD4::{constant#0}>),
HashManyPSD8(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashManyPSD8::{constant#0}>),
Inv(Literals<N, InvOperation<N>, 1>),
IsEq(IsInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::is::IsEq::{constant#0}>),
IsNeq(IsInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::is::IsNeq::{constant#0}>),
LessThan(Literals<N, LessThanOperation<N>, 2>),
LessThanOrEqual(Literals<N, LessThanOrEqualOperation<N>, 2>),
Modulo(Literals<N, ModuloOperation<N>, 2>),
Mul(Literals<N, MulOperation<N>, 2>),
MulWrapped(Literals<N, MulWrappedOperation<N>, 2>),
Nand(Literals<N, NandOperation<N>, 2>),
Neg(Literals<N, NegOperation<N>, 1>),
Nor(Literals<N, NorOperation<N>, 2>),
Not(Literals<N, NotOperation<N>, 1>),
Or(Literals<N, OrOperation<N>, 2>),
Pow(Literals<N, PowOperation<N>, 2>),
PowWrapped(Literals<N, PowWrappedOperation<N>, 2>),
Rem(Literals<N, RemOperation<N>, 2>),
RemWrapped(Literals<N, RemWrappedOperation<N>, 2>),
SerializeBits(SerializeInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::serialize::SerializeBits::{constant#0}>),
SerializeBitsRaw(SerializeInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::serialize::SerializeBitsRaw::{constant#0}>),
Shl(Literals<N, ShlOperation<N>, 2>),
ShlWrapped(Literals<N, ShlWrappedOperation<N>, 2>),
Shr(Literals<N, ShrOperation<N>, 2>),
ShrWrapped(Literals<N, ShrWrappedOperation<N>, 2>),
SignVerify(SignatureVerification<N>),
Square(Literals<N, SquareOperation<N>, 1>),
SquareRoot(Literals<N, SquareRootOperation<N>, 1>),
Sub(Literals<N, SubOperation<N>, 2>),
SubWrapped(Literals<N, SubWrappedOperation<N>, 2>),
Ternary(Literals<N, TernaryOperation<N>, 3>),
Xor(Literals<N, XorOperation<N>, 2>),
}Variants
Abs(Literals<N, AbsOperation<N>, 1>)
Compute the absolute value of first, checking for overflow, and storing the outcome in destination.
AbsWrapped(Literals<N, AbsWrappedOperation<N>, 1>)
Compute the absolute value of first, wrapping around at the boundary of the type, and storing the outcome in destination.
Add(Literals<N, AddOperation<N>, 2>)
Adds first with second, storing the outcome in destination.
AddWrapped(Literals<N, AddWrappedOperation<N>, 2>)
Adds first with second, wrapping around at the boundary of the type, and storing the outcome in destination.
And(Literals<N, AndOperation<N>, 2>)
Performs a bitwise and operation on first and second, storing the outcome in destination.
AssertEq(AssertInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::assert::AssertEq::{constant#0}>)
Asserts first and second are equal.
AssertNeq(AssertInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::assert::AssertNeq::{constant#0}>)
Asserts first and second are not equal.
Async(Async<N>)
Calls a finalize asynchronously on the operands.
Call(Call<N>)
Calls a closure or function on the operands.
Cast(CastOperation<N, snarkvm_synthesizer_program::::logic::instruction::operation::cast::Cast::{constant#0}>)
Casts the operands into the declared type.
CastLossy(CastOperation<N, snarkvm_synthesizer_program::::logic::instruction::operation::cast::CastLossy::{constant#0}>)
Casts the operands into the declared type, with lossy truncation if applicable.
CommitBHP256(CommitInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::commit::CommitBHP256::{constant#0}>)
Performs a BHP commitment on inputs of 256-bit chunks.
CommitBHP512(CommitInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::commit::CommitBHP512::{constant#0}>)
Performs a BHP commitment on inputs of 512-bit chunks.
CommitBHP768(CommitInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::commit::CommitBHP768::{constant#0}>)
Performs a BHP commitment on inputs of 768-bit chunks.
CommitBHP1024(CommitInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::commit::CommitBHP1024::{constant#0}>)
Performs a BHP commitment on inputs of 1024-bit chunks.
CommitPED64(CommitInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::commit::CommitPED64::{constant#0}>)
Performs a Pedersen commitment on up to a 64-bit input.
CommitPED128(CommitInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::commit::CommitPED128::{constant#0}>)
Performs a Pedersen commitment on up to a 128-bit input.
DeserializeBits(DeserializeInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::deserialize::DeserializeBits::{constant#0}>)
Deserializes the bits into a value.
DeserializeBitsRaw(DeserializeInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::deserialize::DeserializeBitsRaw::{constant#0}>)
Deserializes the raw bits into a value.
Div(Literals<N, DivOperation<N>, 2>)
Divides first by second, storing the outcome in destination.
DivWrapped(Literals<N, DivWrappedOperation<N>, 2>)
Divides first by second, wrapping around at the boundary of the type, and storing the outcome in destination.
Double(Literals<N, DoubleOperation<N>, 1>)
Doubles first, storing the outcome in destination.
ECDSAVerifyDigest(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyDigest::{constant#0}>)
Computes whether signature is valid for the given signer and digest using ECDSA.
ECDSAVerifyDigestEth(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyDigestEth::{constant#0}>)
Computes whether signature is valid for the given Ethereum address and digest using ECDSA.
ECDSAVerifyKeccak256(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak256::{constant#0}>)
Computes whether signature is valid for the given signer and message using ECDSA with Keccak256.
ECDSAVerifyKeccak256Raw(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak256Raw::{constant#0}>)
Computes whether signature is valid for the given signer and message using ECDSA with Keccak256 and raw inputs.
ECDSAVerifyKeccak256Eth(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak256Eth::{constant#0}>)
Computes whether signature is valid for the given Ethereum address and message using ECDSA with Keccak256 and raw inputs.
ECDSAVerifyKeccak384(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak384::{constant#0}>)
Computes whether signature is valid for the given signer and message using ECDSA with Keccak384.
ECDSAVerifyKeccak384Raw(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak384Raw::{constant#0}>)
Computes whether signature is valid for the given signer and message using ECDSA with Keccak384 and raw inputs.
ECDSAVerifyKeccak384Eth(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak384Eth::{constant#0}>)
Computes whether signature is valid for the given Ethereum address and message using ECDSA with Keccak384 and raw inputs.
ECDSAVerifyKeccak512(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak512::{constant#0}>)
Computes whether signature is valid for the given signer and message using ECDSA with Keccak512.
ECDSAVerifyKeccak512Raw(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak512Raw::{constant#0}>)
Computes whether signature is valid for the given signer and message using ECDSA with Keccak512 and raw inputs.
ECDSAVerifyKeccak512Eth(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifyKeccak512Eth::{constant#0}>)
Computes whether signature is valid for the given Ethereum address and message using ECDSA with Keccak512 and raw inputs.
ECDSAVerifySha3_256(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_256::{constant#0}>)
Computes whether signature is valid for the given signer and message using ECDSA with SHA3-256.
ECDSAVerifySha3_256Raw(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_256Raw::{constant#0}>)
Computes whether signature is valid for the given signer and message using ECDSA with SHA3-256 and raw inputs.
ECDSAVerifySha3_256Eth(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_256Eth::{constant#0}>)
Computes whether signature is valid for the given Ethereum address and message using ECDSA with SHA3-256 and raw inputs.
ECDSAVerifySha3_384(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_384::{constant#0}>)
Computes whether signature is valid for the given signer and message using ECDSA with SHA3-384.
ECDSAVerifySha3_384Raw(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_384Raw::{constant#0}>)
Computes whether signature is valid for the given signer and message using ECDSA with SHA3-384 and raw inputs.
ECDSAVerifySha3_384Eth(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_384Eth::{constant#0}>)
Computes whether signature is valid for the given Ethereum address and message using ECDSA with SHA3-384 and raw inputs.
ECDSAVerifySha3_512(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_512::{constant#0}>)
Computes whether signature is valid for the given signer and message using ECDSA with SHA3-512.
ECDSAVerifySha3_512Raw(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_512Raw::{constant#0}>)
Computes whether signature is valid for the given signer and message using ECDSA with SHA3-512 and raw inputs.
ECDSAVerifySha3_512Eth(ECDSAVerify<N, snarkvm_synthesizer_program::::logic::instruction::operation::ecdsa_verify::ECDSAVerifySha3_512Eth::{constant#0}>)
Computes whether signature is valid for the given Ethereum address and message using ECDSA with SHA3-512 and raw inputs.
GreaterThan(Literals<N, GreaterThanOperation<N>, 2>)
Computes whether first is greater than second as a boolean, storing the outcome in destination.
GreaterThanOrEqual(Literals<N, GreaterThanOrEqualOperation<N>, 2>)
Computes whether first is greater than or equal to second as a boolean, storing the outcome in destination.
HashBHP256(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP256::{constant#0}>)
Performs a BHP hash on inputs of 256-bit chunks.
HashBHP256Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP256Raw::{constant#0}>)
Performs a BHP hash on the input’s raw bits in 256-bit chunks.
HashBHP512(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP512::{constant#0}>)
Performs a BHP hash on inputs of 512-bit chunks.
HashBHP512Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP512Raw::{constant#0}>)
Performs a BHP hash on the input’s raw bits in 512-bit chunks.
HashBHP768(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP768::{constant#0}>)
Performs a BHP hash on inputs of 768-bit chunks.
HashBHP768Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP768Raw::{constant#0}>)
Performs a BHP hash on the input’s raw bits in 768-bit chunks.
HashBHP1024(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP1024::{constant#0}>)
Performs a BHP hash on inputs of 1024-bit chunks.
HashBHP1024Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashBHP1024Raw::{constant#0}>)
Performs a BHP hash on the input’s raw bits in 1024-bit chunks.
HashKeccak256(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak256::{constant#0}>)
Performs a Keccak hash on the input, outputting 256 bits, hashing the result with BHP256.
HashKeccak256Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak256Raw::{constant#0}>)
Performs a Keccak hash on the input’s raw bits, hashing the result with BHP256.
HashKeccak256Native(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak256Native::{constant#0}>)
Performs a Keccak hash on the input, outputting 256 bits.
HashKeccak256NativeRaw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak256NativeRaw::{constant#0}>)
Performs a Keccak hash on the input’s raw bits, outputting 256 bits.
HashKeccak384(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak384::{constant#0}>)
Performs a Keccak hash on the input, outputting 384 bits, hashing the result with BHP512.
HashKeccak384Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak384Raw::{constant#0}>)
Performs a Keccak hash on the input’s raw bits, outputting 384 bits, hashing the result with BHP512.
HashKeccak384Native(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak384Native::{constant#0}>)
Performs a Keccak hash on the input, outputting 384 bits.
HashKeccak384NativeRaw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak384NativeRaw::{constant#0}>)
Performs a Keccak hash on the input’s raw bits, outputting 384 bits.
HashKeccak512(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak512::{constant#0}>)
Performs a Keccak hash on the input, outputting 512 bits, hashing the result with BHP512.
HashKeccak512Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak512Raw::{constant#0}>)
Performs a Keccak hash on the input’s raw bits, outputting 512 bits, hashing the result with BHP512.
HashKeccak512Native(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak512Native::{constant#0}>)
Performs a Keccak hash on the input, outputting 512 bits.
HashKeccak512NativeRaw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashKeccak512NativeRaw::{constant#0}>)
Performs a Keccak hash on the input’s raw bits, outputting 512 bits.
HashPED64(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPED64::{constant#0}>)
Performs a Pedersen hash on up to a 64-bit input.
HashPED64Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPED64Raw::{constant#0}>)
Performs a Pedersen hash on the input’s raw bits up to a 64-bit input.
HashPED128(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPED128::{constant#0}>)
Performs a Pedersen hash on up to a 128-bit input.
HashPED128Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPED128Raw::{constant#0}>)
Performs a Pedersen hash on the input’s raw bits up to a 128-bit input.
HashPSD2(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPSD2::{constant#0}>)
Performs a Poseidon hash with an input rate of 2.
HashPSD2Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPSD2Raw::{constant#0}>)
Performs a Poseidon hash on the input’s raw fields with an input rate of 2.
HashPSD4(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPSD4::{constant#0}>)
Performs a Poseidon hash with an input rate of 4.
HashPSD4Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPSD4Raw::{constant#0}>)
Performs a Poseidon hash on the input’s raw fields with an input rate of 4.
HashPSD8(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPSD8::{constant#0}>)
Performs a Poseidon hash with an input rate of 8.
HashPSD8Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashPSD8Raw::{constant#0}>)
Performs a Poseidon hash on the input’s raw fields with an input rate of 8.
HashSha3_256(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_256::{constant#0}>)
Performs a SHA-3 hash on the input, outputting 256 bits, hashing the result with BHP256.
HashSha3_256Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_256Raw::{constant#0}>)
Performs a SHA-3 hash on the input’s raw bits, outputting 256 bits, hashing the result with BHP256.
HashSha3_256Native(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_256Native::{constant#0}>)
Performs a SHA-3 hash on the input’s bits, outputting 256 bits.
HashSha3_256NativeRaw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_256NativeRaw::{constant#0}>)
Performs a SHA-3 hash on the input’s raw bits, outputting 256 bits.
HashSha3_384(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_384::{constant#0}>)
Performs a SHA-3 hash on the input, outputting 384 bits, hashing the result with BHP512.
HashSha3_384Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_384Raw::{constant#0}>)
Performs a SHA-3 hash on the input’s raw bits, outputting 384 bits, hashing the result with BHP512.
HashSha3_384Native(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_384Native::{constant#0}>)
Performs a SHA-3 hash on the input’s bits, outputting 384 bits.
HashSha3_384NativeRaw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_384NativeRaw::{constant#0}>)
Performs a SHA-3 hash on the input’s raw bits, outputting 384 bits.
HashSha3_512(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_512::{constant#0}>)
Performs a SHA-3 hash, outputting 512 bits, hashing the result with BHP512.
HashSha3_512Raw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_512Raw::{constant#0}>)
Performs a SHA-3 hash on the input’s raw bits, outputting 512 bits, hashing the result with BHP512.
HashSha3_512Native(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_512Native::{constant#0}>)
Performs a SHA-3 hash on the input’s bits, outputting 512 bits.
HashSha3_512NativeRaw(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashSha3_512NativeRaw::{constant#0}>)
Performs a SHA-3 hash on the input’s raw bits, outputting 512 bits.
HashManyPSD2(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashManyPSD2::{constant#0}>)
Performs a Poseidon hash with an input rate of 2.
HashManyPSD4(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashManyPSD4::{constant#0}>)
Performs a Poseidon hash with an input rate of 4.
HashManyPSD8(HashInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::hash::HashManyPSD8::{constant#0}>)
Performs a Poseidon hash with an input rate of 8.
Inv(Literals<N, InvOperation<N>, 1>)
Computes the multiplicative inverse of first, storing the outcome in destination.
IsEq(IsInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::is::IsEq::{constant#0}>)
Computes whether first equals second as a boolean, storing the outcome in destination.
IsNeq(IsInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::is::IsNeq::{constant#0}>)
Computes whether first does not equals second as a boolean, storing the outcome in destination.
LessThan(Literals<N, LessThanOperation<N>, 2>)
Computes whether first is less than second as a boolean, storing the outcome in destination.
LessThanOrEqual(Literals<N, LessThanOrEqualOperation<N>, 2>)
Computes whether first is less than or equal to second as a boolean, storing the outcome in destination.
Modulo(Literals<N, ModuloOperation<N>, 2>)
Computes first mod second, storing the outcome in destination.
Mul(Literals<N, MulOperation<N>, 2>)
Multiplies first with second, storing the outcome in destination.
MulWrapped(Literals<N, MulWrappedOperation<N>, 2>)
Multiplies first with second, wrapping around at the boundary of the type, and storing the outcome in destination.
Nand(Literals<N, NandOperation<N>, 2>)
Returns false if first and second are true, storing the outcome in destination.
Neg(Literals<N, NegOperation<N>, 1>)
Negates first, storing the outcome in destination.
Nor(Literals<N, NorOperation<N>, 2>)
Returns true if neither first nor second is true, storing the outcome in destination.
Not(Literals<N, NotOperation<N>, 1>)
Flips each bit in the representation of first, storing the outcome in destination.
Or(Literals<N, OrOperation<N>, 2>)
Performs a bitwise or on first and second, storing the outcome in destination.
Pow(Literals<N, PowOperation<N>, 2>)
Raises first to the power of second, storing the outcome in destination.
PowWrapped(Literals<N, PowWrappedOperation<N>, 2>)
Raises first to the power of second, wrapping around at the boundary of the type, storing the outcome in destination.
Rem(Literals<N, RemOperation<N>, 2>)
Divides first by second, storing the remainder in destination.
RemWrapped(Literals<N, RemWrappedOperation<N>, 2>)
Divides first by second, wrapping around at the boundary of the type, storing the remainder in destination.
SerializeBits(SerializeInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::serialize::SerializeBits::{constant#0}>)
Serializes the bits of the input.
SerializeBitsRaw(SerializeInstruction<N, snarkvm_synthesizer_program::::logic::instruction::operation::serialize::SerializeBitsRaw::{constant#0}>)
Serializes the raw bits of the input.
Shl(Literals<N, ShlOperation<N>, 2>)
Shifts first left by second bits, storing the outcome in destination.
ShlWrapped(Literals<N, ShlWrappedOperation<N>, 2>)
Shifts first left by second bits, wrapping around at the boundary of the type, storing the outcome in destination.
Shr(Literals<N, ShrOperation<N>, 2>)
Shifts first right by second bits, storing the outcome in destination.
ShrWrapped(Literals<N, ShrWrappedOperation<N>, 2>)
Shifts first right by second bits, wrapping around at the boundary of the type, storing the outcome in destination.
SignVerify(SignatureVerification<N>)
Computes whether signature is valid for the given address and message.
Square(Literals<N, SquareOperation<N>, 1>)
Squares ‘first’, storing the outcome in destination.
SquareRoot(Literals<N, SquareRootOperation<N>, 1>)
Compute the square root of ‘first’, storing the outcome in destination.
Sub(Literals<N, SubOperation<N>, 2>)
Computes first - second, storing the outcome in destination.
SubWrapped(Literals<N, SubWrappedOperation<N>, 2>)
Computes first - second, wrapping around at the boundary of the type, and storing the outcome in destination.
Ternary(Literals<N, TernaryOperation<N>, 3>)
Selects first, if condition is true, otherwise selects second, storing the result in destination.
Xor(Literals<N, XorOperation<N>, 2>)
Performs a bitwise xor on first and second, storing the outcome in destination.
Implementations
Sourceimpl<N> Instruction<N>where
N: Network,
impl<N> Instruction<N>where
N: Network,
Sourcepub fn is_reserved_opcode(name: &str) -> bool
pub fn is_reserved_opcode(name: &str) -> bool
Returns true if the given name is a reserved opcode.
Sourcepub fn destinations(&self) -> Vec<Register<N>>
pub fn destinations(&self) -> Vec<Register<N>>
Returns the destination registers of the instruction.
Sourcepub fn call_operator(&self) -> Option<&CallOperator<N>>
pub fn call_operator(&self) -> Option<&CallOperator<N>>
Returns the CallOperator if the instruction is a call instruction, otherwise None.
Sourcepub fn evaluate(
&self,
stack: &impl StackTrait<N>,
registers: &mut impl RegistersSigner<N>,
) -> Result<(), Error>
pub fn evaluate( &self, stack: &impl StackTrait<N>, registers: &mut impl RegistersSigner<N>, ) -> Result<(), Error>
Evaluates the instruction.
Sourcepub fn execute<A>(
&self,
stack: &impl StackTrait<N>,
registers: &mut impl RegistersCircuit<N, A>,
) -> Result<(), Error>where
A: Aleo<Network = N>,
pub fn execute<A>(
&self,
stack: &impl StackTrait<N>,
registers: &mut impl RegistersCircuit<N, A>,
) -> Result<(), Error>where
A: Aleo<Network = N>,
Executes the instruction.
Sourcepub fn finalize(
&self,
stack: &impl StackTrait<N>,
registers: &mut impl RegistersTrait<N>,
) -> Result<(), Error>
pub fn finalize( &self, stack: &impl StackTrait<N>, registers: &mut impl RegistersTrait<N>, ) -> Result<(), Error>
Finalizes the instruction.
Sourcepub fn output_types(
&self,
stack: &impl StackTrait<N>,
input_types: &[RegisterType<N>],
) -> Result<Vec<RegisterType<N>>, Error>
pub fn output_types( &self, stack: &impl StackTrait<N>, input_types: &[RegisterType<N>], ) -> Result<Vec<RegisterType<N>>, Error>
Returns the output type from the given input types.
Sourcepub fn contains_external_struct(&self) -> bool
pub fn contains_external_struct(&self) -> bool
Returns whether this instruction refers to an external struct.
Sourcepub fn contains_string_type(&self) -> bool
pub fn contains_string_type(&self) -> bool
Returns true if the instruction contains a literal string type.
Sourcepub fn exceeds_max_array_size(&self, max_array_size: u32) -> bool
pub fn exceeds_max_array_size(&self, max_array_size: u32) -> bool
Returns true if the instruction contains an array type with a size that exceeds the given maximum.